OC.L10N.register(
    "core",
    {
    "Please select a file." : "Pasirinkite failą.",
    "File is too big" : "Failas yra per didelis",
    "The selected file is not an image." : "Pasirinktas failas nėra paveikslas.",
    "The selected file cannot be read." : "Nepavyksta perskaityti pasirinkto failo.",
    "Invalid file provided" : "Pateiktas neteisingas failas",
    "No image or file provided" : "Nenurodytas paveikslas ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslas",
    "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
    "No temporary profile picture available, try again" : "Nėra laikinojo profilio paveikslėlio, bandykite dar kartą",
    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
    "No valid crop data provided" : "Pateikti neteisingi apkirpimo duomenys",
    "Crop is not square" : "Apkirpimo plotas nėra kvadratas",
    "State token does not match" : "Išorinės sistemos leidimai nesutampa su turimais.",
    "Could not complete login" : "Nepavyko užbaigti prisijungimo",
    "Your login token is invalid or has expired" : "Jūsų prieigos raktas yra neteisingas arba pasibaigė jo galiojimo laikas",
    "Password reset is disabled" : "Slaptažodžio atstatymas išjungtas",
    "Couldn't reset password because the token is invalid" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas yra neteisingas",
    "Couldn't reset password because the token is expired" : "Nepavyko atstatyti slaptažodžio, kadangi prieigos rakto galiojimas yra pasibaigęs",
    "%s password reset" : "%s slaptažodžio atstatymas",
    "Password reset" : "Slaptažodžio atstatymas",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite mygtuką slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite nuorodą slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
    "Reset your password" : "Atkurkite savo slaptažodį",
    "Nextcloud Server" : "Nextcloud serveris",
    "Preparing update" : "Ruošiamas atnaujinimas",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Pataisymo žingsnis:",
    "Repair info:" : "Pataisymo informacija:",
    "Repair warning:" : "Taisymo įspėjimas:",
    "Repair error:" : "Taisymo klaida:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatinis atnaujinimas išjungtas config.php faile. Naudokite komandinės eilutės atnaujinimo įrankį.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
    "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
    "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tikrinama ar duomenų bazės struktūra gali būti atnaujinta (priklausomai nuo duomenų bazės dydžio, operacija gali ilgai užtrukti)",
    "Checked database schema update" : "Duomenų bazės struktūros naujinimas patikrintas",
    "Checking updates of apps" : "Tikrinami programėlių atnaujinimai",
    "Checking for update of app \"%s\" in appstore" : "Ieškoma programėlių parduotuvėje atnaujinimo programėlei %s",
    "Update app \"%s\" from appstore" : "Atnaujinkite \"%s\" įskiepį iš programinės įrangos saugyklos",
    "Checked for update of app \"%s\" in appstore" : "Atlikta atnaujinimų paieška įskiepiui \"%s\" programinės įrangos saugykloje",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tikrinama ar %s duomenų bazės struktūra gali būti atnaujinta (priklausomai nuo duomenų bazės dydžio, tai gali ilgai užtrukti)",
    "Checked database schema update for apps" : "Duomenų bazės struktūra paruošta įskiepių atnaujinimui",
    "Updated \"%1$s\" to %2$s" : "Atnaujinta „%1$s“ į %2$s",
    "Set log level to debug" : "Žurnalo išvesties lygis nustatytas į derinimo",
    "Reset log level" : "Atstatyti registravimo lygį",
    "Starting code integrity check" : "Pradedama kodo vientisumo patikra",
    "Finished code integrity check" : "Kodo vientisumo patikra užbaigta",
    "%s (incompatible)" : "%s (nesuderinama)",
    "Following apps have been disabled: %s" : "Šios programėlės buvo išjungtos: %s",
    "Already up to date" : "Naudojama naujausia versija",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Jūsų svetainės serveris nėra sukonfiguruotas atpažinti \"{url}\". Daugiau informacijos rasite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Paskutinis foninis užduočių vykdymas buvo paleistas {relativeTime}. Atrodo, kad kažkas nutiko.",
    "Check the background job settings" : "Peržiūrėkite fone veikiančių užduočių nustatymus",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Kai kurie failai nepraėjo vientisumo patikrinimo. Tolimesnę informaciją apie tai, kaip išspręsti šią problemą, galima rasti <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Neteisingų failų sąrašas…</a> / <a href=\"{rescanEndpoint}\">Peržiūrėti iš naujo…</a>)",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
    "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
    "restricted" : "apribota",
    "invisible" : "nematoma",
    "({scope})" : "({scope})",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "Collaborative tags" : "Bendradarbiavimo žymės",
    "No tags found" : "Nerasta jokių žymių",
    "unknown text" : "nežinomas tekstas",
    "Hello world!" : "Sveikas, pasauli!",
    "sunny" : "saulėta",
    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
    "Hello {name}" : "Sveiki, {name},",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
    "new" : "naujas",
    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "An error occurred." : "Įvyko klaida.",
    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
    "Continue to Nextcloud" : "Eiti į NextCloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Atnaujinimas buvo sėkmingas. Po %n sekundės būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundžių būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundžių būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundės būsite nukreipti į Nextcloud."],
    "Searching other places" : "Ieškoma kitose vietose",
    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} paieškos rezultatas kitame aplanke","{count} paieškos rezultatai kitame aplanke","{count} paieškos rezultatų kitame aplanke","{count} paieškos rezultatas kitame aplanke"],
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
    "An internal error occurred." : "Įvyko vidinė klaida.",
    "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
    "Username or email" : "Naudotojas arba el. paštas",
    "Username or\temail" : "Naudotojo vardas ar\tel. paštas",
    "Password" : "Slaptažodis",
    "Log in" : "Prisijungti",
    "Logging in …" : "Prisijungiama …",
    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
    "User disabled" : "Naudotojas išjungtas",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Aptikome kelis nepavykusius prisijungimus iš jūsų IP adreso. Dėl to prisijungimo dažnis yra apribotas iki 30 sekundžių.",
    "Reset password" : "Atstatyti slaptažodį",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas. Susisiekite su savo administratoriumi.",
    "Back to login" : "Grįžti prie prisijungimo",
    "New password" : "Naujas slaptažodis",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Recommended apps" : "Rekomenduojamos programėlės",
    "Loading apps …" : "Įkeliamos programėlės…",
    "Could not fetch list of apps from the app store." : "Nepavyko iš programėlių parduotuvės gauti programėlių sąrašo.",
    "Installing apps …" : "Įdiegiamos programėlės…",
    "Nextcloud {app}" : "Nextcloud {app}",
    "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
    "Can't install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
    "Can't install this app" : "Nepavyksta įdiegti šios programėlės",
    "Cancel" : "Atsisakyti",
    "Forgot password?" : "Pamiršote slaptažodį?",
    "Settings" : "Nustatymai",
    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
    "Search contacts …" : "Ieškoti adresatų…",
    "No contacts found" : "Adresatų nerasta",
    "Show all contacts …" : "Rodyti visus adresatus...",
    "Install the Contacts app" : "Įdiegti adresatų programėlę",
    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
    "Looking for {term} …" : "Ieškoma {term} ...",
    "No" : "Ne",
    "Yes" : "Taip",
    "No files in here" : "Čia failų nėra",
    "New folder" : "Naujas aplankas",
    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeista",
    "{newName} already exists" : "{newName} jau yra",
    "Choose" : "Pasirinkti",
    "Copy" : "Kopijuoti",
    "Move" : "Perkelti",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "OK" : "Gerai",
    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failų konfliktas","{count} failų konfliktai","{count} failų konfliktų","{count} failų konfliktas"],
    "One file conflict" : "Nesuderinamas failas",
    "New Files" : "Nauji failai",
    "Already existing files" : "Jau esami failai",
    "Which files do you want to keep?" : "Kuriuos failus norite pasilikti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasiliekate abi versijas, prie nukopijuoto failo pavadinimo bus pridėtas skaičius.",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
    "Pending" : "Vykdoma",
    "Copy to {folder}" : "Kopijuoti į {folder}",
    "Move to {folder}" : "Perkelti į {folder}",
    "Saving..." : "Įrašoma...",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
    "Confirm" : "Patvirtinti",
    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
    "seconds ago" : "prieš keletą sekundžių",
    "Connection to server lost" : "Ryšys su serveriu nutrūko",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
    "Add to a project" : "Pridėti į projektą",
    "Hide details" : "Slėpti išsamesnę informaciją",
    "Rename project" : "Pervadinti projektą",
    "Failed to rename the project" : "Nepavyko pervadinti projekto",
    "Failed to create a project" : "Nepavyko sukurti projekto",
    "Failed to add the item to the project" : "Nepavyko pridėti elemento į projektą",
    "Connect items to a project to make them easier to find" : "Susieti elementus su projektu, kad juos būtų lengviau rasti",
    "New in" : "Nauja",
    "View changelog" : "Rodyti keitinių žurnalą",
    "No action available" : "Jokie veiksmai negalimi",
    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
    "Personal" : "Asmeniniai",
    "Users" : "Naudotojai",
    "Apps" : "Programėlės",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Access forbidden" : "Prieiga uždrausta",
    "File not found" : "Failas nerastas",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko rasti dokumento serveryje. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
    "Back to %s" : "Atgal į %s",
    "Error" : "Klaida",
    "Internal Server Error" : "Vidinė serverio klaida",
    "The server was unable to complete your request." : "Serveriui nepavyko įvykdyti jūsų užklausos.",
    "If this happens again, please send the technical details below to the server administrator." : "Jei tai pasikartos, prašome nusiųskite administratoriui žemiau esančią informaciją .",
    "More details can be found in the server log." : "Detalesnė informacija yra sistemos žurnale.",
    "Technical details" : "Techniniai duomenys",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Type: %s" : "Tipas: %s",
    "Code: %s" : "Kodas: %s",
    "Message: %s" : "Žinutė: %s",
    "File: %s" : "Failas: %s",
    "Line: %s" : "Eilutė: %s",
    "Trace" : "Sekti",
    "Security warning" : "Saugumo įspėjimas",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
    "Create an <strong>admin account</strong>" : "Sukurkite <strong>administratoriaus paskyrą</strong>",
    "Username" : "Naudotojo vardas",
    "Show password" : "Rodyti slaptažodį",
    "Storage & database" : "Saugykla ir duomenų bazė",
    "Data folder" : "Duomenų aplankas",
    "Configure the database" : "Konfigūruokite duomenų bazę",
    "Only %s is available." : "Yra prieinama tik %s.",
    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
    "Database user" : "Duomenų bazės naudotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "Performance warning" : "Sistemos našumo problemos perspėjimas",
    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
    "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
    "Finish setup" : "Užbaigti sąranką",
    "Finishing …" : "Užbaigiama …",
    "Need help?" : "Reikia pagalbos?",
    "See the documentation" : "Žiūrėkite dokumentaciją",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nepavyko iš konfigūracijos aplanko pašalinti failo CAN_INSTALL. Pašalinkite šį failą rankiniu būdu.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Sistemos veikimui reikalingas JavaScript palaikymas. Prašome {linkstart}įjungti JavaScript palaikymą{linkend} ir atnaujinti puslapį.",
    "Get your own free account" : "Gaukite asmeninę nemokamą paskyrą",
    "Skip to main content" : "Pereiti į pagrindinį turinį",
    "Skip to navigation of app" : "Pereiti į programėlės naršymą",
    "More apps" : "Daugiau programėlių",
    "More" : "Daugiau",
    "More apps menu" : "Daugiau programėlių meniu",
    "Search" : "Ieškoti",
    "Reset search" : "Atstatyti paiešką",
    "Contacts" : "Adresatai",
    "Contacts menu" : "Adresatų meniu",
    "Settings menu" : "Nustatymų meniu",
    "Confirm your password" : "Patvirtinkite savo slaptažodį",
    "Connect to your account" : "Prisijunkite prie paskyros",
    "Please log in before granting %1$s access to your %2$s account." : "Prisijunkite norėdami suteikti %1$s prie jūsų %2$s paskyros.",
    "App token" : "Išorinės sistemos įskiepio kodas",
    "Grant access" : "Suteikti prieigą",
    "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
    "Account access" : "Paskyros prieiga",
    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
    "Account connected" : "Paskyra prijungta",
    "You can close this window." : "Galite užverti šį langą.",
    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Two-factor authentication" : "Dviejų žingsnių prisijungimas",
    "Use backup code" : "Naudoti atsarginį kodą",
    "Error while validating your second factor" : "Klaida antrame prisijungimo žingsnyje",
    "Access through untrusted domain" : "Prieiga iš nepatikimo domeno",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Susisiekite su savo administratoriumi. Jeigu jūs esate administratorius, pataisykite \"trusted_domains\" nustatymą config/config.php faile, kaip tai parodyta pavyzdyje config.sample.php faile.",
    "App update required" : "Reikalingas programėlės atnaujinimas",
    "%1$s will be updated to version %2$s" : "%1$s bus atnaujinta į versiją %2$s",
    "These apps will be updated:" : "Bus atnaujintos šios programėlės:",
    "These incompatible apps will be disabled:" : "Bus išjungtos šios nesuderinamos programėlės:",
    "The theme %s has been disabled." : "Apipavidalinimas %s buvo išjungtas.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prieš tęsdami, įsitikinkite, kad pasidarėte duomenų bazės, konfigūracijos aplanko bei duomenų aplanko atsarginę kopiją.",
    "Start update" : "Pradėti atnaujinimą",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Naudodami didesnius diegimus ir norėdami išvengti laukimo laiko, vietoj to, savo diegimo kataloge galite paleisti šią komandą:",
    "Detailed logs" : "Išsamūs žurnalai",
    "Update needed" : "Reikalingas atnaujinimas",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
    "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
    "Maintenance mode" : "Techninės priežiūros veiksena",
    "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
    "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško dėl to, kad šiam naudotojo vardui nėra nustatytas joks el. pašto adresas. Susisiekite su savo administratoriumi.",
    "Couldn't send reset email. Please make sure your username is correct." : "Nepavyko išsiųsti atstatymo el. laiško. Prašome įsitikinti, kad jūsų naudotojo vardas yra teisingas.",
    "Dismiss" : "Atmesti",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Slaptažodžio atkūrimo nuoroda buvo išsiųsta nurodytu elektroninio pašto adresu. Jei greitu laiku negausite laiško, patikrinkite \"šlamšto\" skyrių elektroniniame pašte. <br> Jei laiško vis tiek nerandate, susiekite su sistemos administratoriumi.",
    "Sending email …" : "Siunčiamas el. laiškas ...",
    "Shared" : "Bendrinama",
    "Shared with" : "Bendrinama su",
    "Shared by" : "Bendrina",
    "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
    "Choose a password for the public link or press the \"Enter\" key" : "Įrašykite slaptažodį viešai nuorodai ir spustelėkite „Enter“ klavišą",
    "Copied!" : "Nukopijuota!",
    "Copy link" : "Kopijuoti nuorodą",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Norėdami nukopijuoti, paspauskite Ctrl-C.",
    "Unable to toggle this option" : "Nepavyko perjungti pasirinkimo",
    "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
    "Link" : "Nuoroda",
    "Hide download" : "Slėpti atsisiuntimą",
    "Password protection enforced" : "Aktyvuota apsauga slaptažodžiu",
    "Password protect" : "Apsaugoti slaptažodžiu",
    "Allow editing" : "Leisti redaguoti",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "Allow upload and editing" : "Leisti įkelti ir redaguoti",
    "Read only" : "Tik skaitymui",
    "File drop (upload only)" : "Failų įmetimas (tik įkėlimas)",
    "Expiration date enforced" : "Aktyvuotas galiojimo laikas",
    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
    "Expiration" : "Veikimo pabaiga",
    "Expiration date" : "Galiojimo pabaiga",
    "Note to recipient" : "Pastaba gavėjui",
    "Unshare" : "Nustoti bendrinti",
    "Delete share link" : "Ištrinti bendrinimo nuorodą",
    "Add another link" : "Pridėti dar vieną nuorodą",
    "Password protection for links is mandatory" : "Nuorodų apsauga slaptažodžiu yra privaloma",
    "Share to {name}" : "Parodyti asmeniui vardu {name}",
    "Share link" : "Bendrinimo nuoroda",
    "New share link" : "Nauja bendrinimo nuoroda",
    "Created on {time}" : "Sukurta {time}",
    "Password protect by Talk" : "„Talk“ apsauga slaptažodžiu",
    "Could not unshare" : "Nepavyko nustoti bendrinti",
    "Shared with you and the group {group} by {owner}" : "{owner} pradėjo bendrinti su jumis ir su grupe {group}",
    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
    "Choose a password for the mail share" : "Pasirinkite slaptažodį pasidalinimui per elektroninį paštą",
    "group" : "grupė",
    "remote" : "nuotolinis",
    "remote group" : "nuotolinė grupė",
    "email" : "elektroninis paštas",
    "conversation" : "pokalbis",
    "shared by {sharer}" : "bendrina {sharer}",
    "Can reshare" : "Gali pakartotinai bendrinti",
    "Can edit" : "Gali redaguoti",
    "Can create" : "Galima kurti nauja",
    "Can change" : "Galima keisti",
    "Can delete" : "Galima trinti",
    "Access control" : "Prieigos valdymas",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} pradėjo bendrinti per nuorodą",
    "Error while sharing" : "Klaida bendrinant",
    "Share details could not be loaded for this item." : "Dalinimosi detalės negali būti atskleistos šiai bylai",
    "This list is maybe truncated - please refine your search term to see more results." : "Sąrašas galimai sutrumpintas - prašome patikslinti paiešką, norint matyti daugiau rezultatų.",
    "No users or groups found for {search}" : "Pagal užklausą {search}, nerasta jokių naudotojų ar grupių",
    "No users found for {search}" : "Nerasta vartotojų pagal paieškos kriterijų: {search}",
    "An error occurred (\"{message}\"). Please try again" : "Įvyko klaida (\"{message}\"). Bandykite dar kartą",
    "An error occurred. Please try again" : "Įvyko klaida. Bandykite dar kartą",
    "Home" : "Namų",
    "Work" : "Darbo",
    "Other" : "Kitas",
    "{sharee} (remote group)" : "{sharee} (išorinė grupė) ",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Dalintis",
    "Name or email address..." : "Vardas arba elektroninio pašto adresas...",
    "Name or federated cloud ID..." : "Vardas ar federacinės debesijos ID...",
    "Name, federated cloud ID or email address..." : "Vardas, federacinės debesijos ID arba el. pašto adresas...",
    "Name..." : "Vardas...",
    "Error removing share" : "Klaida šalinant viešinį",
    "SQLite will be used as database." : "SQLite bus naudojama kaip duomenų bazė.",
    "For larger installations we recommend to choose a different database backend." : "Didesnei sistemai įdiegti rekomenduojame pasirinkti kitą duomenų bazę.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite naudojimas yra nerekomenduotinas, kai duomenų sinchronizacijai naudojamas darbalaukio klientas.",
    "Wrong password." : "Neteisingas slaptažodis.",
    "New Password" : "Naujas slaptažodis",
    "Cancel log in" : "Atšaukti prisijungimą",
    "Search globally" : "Ieškoti visur",
    "Your client should now be connected! You can close this window." : "Klientas jau turi būti prijungtas! Langą galite užverti."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
